==> appassembler-maven-plugin-1.2-sources.jar: org/codehaus/mojo/appassembler/daemon/script/AbstactScriptDaemonGenerator.java <==
/**
 * The MIT License
 *
 * Copyright 2006-2011 The Codehaus.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.codehaus.mojo.appassembler.daemon.script;

import org.codehaus.mojo.appassembler.daemon.DaemonGenerator;

public abstract class AbstactScriptDaemonGenerator
        implements DaemonGenerator
{
    /**
     * @plexus.requirement
     */
    protected ScriptGenerator scriptGenerator;

    private final String platformName;

    public AbstactScriptDaemonGenerator ( String platformName )
    {
        this.platformName = platformName;
    }

    public String getPlatformName ()
    {
        return platformName;
    }
}

==> appassembler-maven-plugin-1.2.2-sources.jar: org/codehaus/mojo/appassembler/daemon/script/AbstactScriptDaemonGenerator.java <==
/**
 * The MIT License
 *
 * Copyright 2006-2012 The Codehaus.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.codehaus.mojo.appassembler.daemon.script;

import org.codehaus.mojo.appassembler.daemon.DaemonGenerator;

/**
 * The abstract script daemon generator which contains all common parameters and
 * methods for AbstractBooterDaemonGenerator, UnixScriptDaemonGenerator
 * and WindowsScriptDaemonGenerator
 * 
 * @author <a href="mailto:khmarbaise@soebes.de">Karl-Heinz Marbaise</a>
 *
 */
public abstract class AbstactScriptDaemonGenerator
        implements DaemonGenerator
{
    /**
     * @plexus.requirement
     */
    protected ScriptGenerator scriptGenerator;

    private final String platformName;

    public AbstactScriptDaemonGenerator ( String platformName )
    {
        this.platformName = platformName;
    }

    public String getPlatformName ()
    {
        return platformName;
    }
}
